==> browserify-3.14.1.tgz: package/lib/builtins.js <==
exports.assert = require.resolve('assert/');
exports.buffer = require.resolve('native-buffer-browserify');
exports.child_process = require.resolve('../_empty.js');
exports.cluster = require.resolve('../_empty.js');
exports.console = require.resolve('console-browserify');
exports.constants = require.resolve('constants-browserify');
exports.crypto = require.resolve('crypto-browserify');
exports.dgram = require.resolve('../_empty.js');
exports.dns = require.resolve('../_empty.js');
exports.domain = require.resolve('domain-browser');
exports.events = require.resolve('events/');
exports.fs = require.resolve('../_empty.js');
exports.http = require.resolve('http-browserify');
exports.https = require.resolve('https-browserify');
exports.module = require.resolve('../_empty.js');
exports.net = require.resolve('../_empty.js');
exports.os = require.resolve('os-browserify/browser.js');
exports.path = require.resolve('path-browserify');
exports.punycode = require.resolve('punycode/');
exports.querystring = require.resolve('querystring/');
exports.readline = require.resolve('../_empty.js');
exports.repl = require.resolve('../_empty.js');
exports.stream = require.resolve('stream-browserify');
exports._stream_duplex = require.resolve('stream-browserify/duplex.js');
exports._stream_passthrough = require.resolve('stream-browserify/passthrough.js');
exports._stream_readable = require.resolve('stream-browserify/readable.js');
exports._stream_transform = require.resolve('stream-browserify/transform.js');
exports._stream_writable = require.resolve('stream-browserify/writable.js');
exports.string_decoder = require.resolve('string_decoder/');
exports.sys = require.resolve('util/util.js');
exports.timers = require.resolve('timers-browserify');
exports.tty = require.resolve('tty-browserify');
exports.url = require.resolve('url/');
exports.util = require.resolve('util/util.js');
exports.vm = require.resolve('vm-browserify');
exports.zlib = require.resolve('zlib-browserify');

==> browserify-3.24.4.tgz: package/lib/builtins.js <==
exports.assert = require.resolve('assert/');
exports.buffer = require.resolve('native-buffer-browserify');
exports.child_process = require.resolve('./_empty.js');
exports.cluster = require.resolve('./_empty.js');
exports.console = require.resolve('console-browserify');
exports.constants = require.resolve('constants-browserify');
exports.crypto = require.resolve('crypto-browserify');
exports.dgram = require.resolve('./_empty.js');
exports.dns = require.resolve('./_empty.js');
exports.domain = require.resolve('domain-browser');
exports.events = require.resolve('events/');
exports.fs = require.resolve('./_empty.js');
exports.http = require.resolve('http-browserify');
exports.https = require.resolve('https-browserify');
exports.module = require.resolve('./_empty.js');
exports.net = require.resolve('./_empty.js');
exports.os = require.resolve('os-browserify/browser.js');
exports.path = require.resolve('path-browserify');
exports.punycode = require.resolve('punycode/');
exports.querystring = require.resolve('querystring/');
exports.readline = require.resolve('./_empty.js');
exports.repl = require.resolve('./_empty.js');
exports.stream = require.resolve('stream-browserify');
exports._stream_duplex = require.resolve('stream-browserify/duplex.js');
exports._stream_passthrough = require.resolve('stream-browserify/passthrough.js');
exports._stream_readable = require.resolve('stream-browserify/readable.js');
exports._stream_transform = require.resolve('stream-browserify/transform.js');
exports._stream_writable = require.resolve('stream-browserify/writable.js');
exports.string_decoder = require.resolve('string_decoder/');
exports.sys = require.resolve('util/util.js');
exports.timers = require.resolve('timers-browserify');
exports.tty = require.resolve('tty-browserify');
exports.url = require.resolve('url/');
exports.util = require.resolve('util/util.js');
exports.vm = require.resolve('vm-browserify');
exports.zlib = require.resolve('zlib-browserify');
